==> certmanager-model-v1beta1-5.10.2-sources.jar: annotations/io/fabric8/certmanager/api/model/acme/v1beta1/OrderStatusFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OrderStatusFluent<A extends io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAuthorizations(java.lang.Integer index,io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization item);
  public A setToAuthorizations(java.lang.Integer index,io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization item);
  public A addToAuthorizations(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization... items);
  public A addAllToAuthorizations(java.util.Collection<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> items);
  public A removeFromAuthorizations(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization... items);
  public A removeAllFromAuthorizations(java.util.Collection<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> items);
  public A removeMatchingFromAuthorizations(java.util.function.Predicate<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAuthorizations instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> getAuthorizations();
  public java.util.List<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> buildAuthorizations();
  public io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization buildAuthorization(java.lang.Integer index);
  public io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization buildFirstAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization buildLastAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization buildMatchingAuthorization(java.util.function.Predicate<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationBuilder> predicate);
  public java.lang.Boolean hasMatchingAuthorization(java.util.function.Predicate<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationBuilder> predicate);
  public A withAuthorizations(java.util.List<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> authorizations);
  public A withAuthorizations(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization... authorizations);
  public java.lang.Boolean hasAuthorizations();
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> addNewAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> addNewAuthorizationLike(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization item);
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> setNewAuthorizationLike(java.lang.Integer index,io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization item);
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> editAuthorization(java.lang.Integer index);
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> editFirstAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> editLastAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> editMatchingAuthorization(java.util.function.Predicate<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationBuilder> predicate);
  public A addToCertificate(java.lang.Integer index,java.lang.Integer item);
  public A setToCertificate(java.lang.Integer index,java.lang.Integer item);
  public A addToCertificate(java.lang.Integer... items);
  public A addAllToCertificate(java.util.Collection<java.lang.Integer> items);
  public A removeFromCertificate(java.lang.Integer... items);
  public A removeAllFromCertificate(java.util.Collection<java.lang.Integer> items);
  public java.util.List<java.lang.Integer> getCertificate();
  public java.lang.Integer getCertificate(java.lang.Integer index);
  public java.lang.Integer getFirstCertificate();
  public java.lang.Integer getLastCertificate();
  public java.lang.Integer getMatchingCertificate(java.util.function.Predicate<java.lang.Integer> predicate);
  public java.lang.Boolean hasMatchingCertificate(java.util.function.Predicate<java.lang.Integer> predicate);
  public A withCertificate(java.util.List<java.lang.Integer> certificate);
  public A withCertificate(java.lang.Integer... certificate);
  public java.lang.Boolean hasCertificate();
  public java.lang.String getFailureTime();
  public A withFailureTime(java.lang.String failureTime);
  public java.lang.Boolean hasFailureTime();
  
  /**
   * Method is deprecated. use withFailureTime instead.
   */
  @java.lang.Deprecated
  public A withNewFailureTime(java.lang.String arg0);
  public java.lang.String getFinalizeURL();
  public A withFinalizeURL(java.lang.String finalizeURL);
  public java.lang.Boolean hasFinalizeURL();
  
  /**
   * Method is deprecated. use withFinalizeURL instead.
   */
  @java.lang.Deprecated
  public A withNewFinalizeURL(java.lang.String arg0);
  public java.lang.String getReason();
  public A withReason(java.lang.String reason);
  public java.lang.Boolean hasReason();
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0);
  public java.lang.String getState();
  public A withState(java.lang.String state);
  public java.lang.Boolean hasState();
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0);
  public java.lang.String getUrl();
  public A withUrl(java.lang.String url);
  public java.lang.Boolean hasUrl();
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0);
  public interface AuthorizationsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationFluent<io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  
}

==> certmanager-model-v1beta1-5.12.0-sources.jar: annotations/io/fabric8/certmanager/api/model/acme/v1beta1/OrderStatusFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OrderStatusFluent<A extends io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAuthorizations(java.lang.Integer index,io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization item);
  public A setToAuthorizations(java.lang.Integer index,io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization item);
  public A addToAuthorizations(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization... items);
  public A addAllToAuthorizations(java.util.Collection<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> items);
  public A removeFromAuthorizations(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization... items);
  public A removeAllFromAuthorizations(java.util.Collection<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> items);
  public A removeMatchingFromAuthorizations(java.util.function.Predicate<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAuthorizations instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> getAuthorizations();
  public java.util.List<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> buildAuthorizations();
  public io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization buildAuthorization(java.lang.Integer index);
  public io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization buildFirstAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization buildLastAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization buildMatchingAuthorization(java.util.function.Predicate<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationBuilder> predicate);
  public java.lang.Boolean hasMatchingAuthorization(java.util.function.Predicate<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationBuilder> predicate);
  public A withAuthorizations(java.util.List<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization> authorizations);
  public A withAuthorizations(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization... authorizations);
  public java.lang.Boolean hasAuthorizations();
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> addNewAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> addNewAuthorizationLike(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization item);
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> setNewAuthorizationLike(java.lang.Integer index,io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorization item);
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> editAuthorization(java.lang.Integer index);
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> editFirstAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> editLastAuthorization();
  public io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<A> editMatchingAuthorization(java.util.function.Predicate<io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationBuilder> predicate);
  public java.lang.String getCertificate();
  public A withCertificate(java.lang.String certificate);
  public java.lang.Boolean hasCertificate();
  
  /**
   * Method is deprecated. use withCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewCertificate(java.lang.String arg0);
  public java.lang.String getFailureTime();
  public A withFailureTime(java.lang.String failureTime);
  public java.lang.Boolean hasFailureTime();
  
  /**
   * Method is deprecated. use withFailureTime instead.
   */
  @java.lang.Deprecated
  public A withNewFailureTime(java.lang.String arg0);
  public java.lang.String getFinalizeURL();
  public A withFinalizeURL(java.lang.String finalizeURL);
  public java.lang.Boolean hasFinalizeURL();
  
  /**
   * Method is deprecated. use withFinalizeURL instead.
   */
  @java.lang.Deprecated
  public A withNewFinalizeURL(java.lang.String arg0);
  public java.lang.String getReason();
  public A withReason(java.lang.String reason);
  public java.lang.Boolean hasReason();
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0);
  public java.lang.String getState();
  public A withState(java.lang.String state);
  public java.lang.Boolean hasState();
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0);
  public java.lang.String getUrl();
  public A withUrl(java.lang.String url);
  public java.lang.Boolean hasUrl();
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0);
  public interface AuthorizationsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.certmanager.api.model.acme.v1beta1.ACMEAuthorizationFluent<io.fabric8.certmanager.api.model.acme.v1beta1.OrderStatusFluent.AuthorizationsNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  
}
